@@ -6,7 +6,7 @@ use Fennec::Assert;
 use Fennec::Assert::Core::More;
 use Fennec::Output::Result;
 
-util $_ for qw/warning_is warnings_are warning_like/;
+util $_ for qw/warning_is warnings_are warning_like capture_warnings/;
 tester $_ for qw/warnings_like warnings_exist/;
 
 sub capture_warnings(&) {
@@ -107,3 +107,17 @@ sub warnings_exist(&$;$) {
 }
 
 1;
+
+=head1 AUTHORS
+
+Chad Granum L<exodist7@gmail.com>
+
+=head1 COPYRIGHT
+
+Copyright (C) 2010 Chad Granum
+
+Fennec is free software; Standard perl licence.
+
+Fennec is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+FOR A PARTICULAR PURPOSE.  See the license for more details.
