@@ -116,11 +116,11 @@ sub data {
 sub load {
     my $self = shift;
     return 1 if $self->[1]++;
-    Fennec->clear_test_class;
+    Fennec->_clear_test_class;
 
     $self->load_file( $self->[0] );
 
-    my $tclass = Fennec->test_class;
+    my $tclass = Fennec->_test_class;
     croak( "loading '" . $self->[0] . "' did not produce a test class" )
         unless $tclass;
     return $tclass;
