@@ -2,7 +2,26 @@ package Fennec::Util;
 use strict;
 use warnings;
 
-use Carp;
+use Carp qw/carp confess croak cluck/;
+
+sub workflow_stack {
+    my $class = shift;
+    my ( $workflow ) = @_;
+    return wantarray ? () : 'No Workflow' unless $workflow;
+
+    my @list;
+    my $current = $workflow;
+
+    do {
+        push @list => $current;
+    } while (( $current = $current->parent ) && $current->isa( 'Fennec::Workflow' ));
+    return reverse @list if wantarray;
+
+    my @lines = map {
+        join( ' ', $_->name || "UNNAMED", '-', $_->file || "UNKNOWN FILE", 'at', $_->line || "UNKNOWN LINE" )
+    } @list;
+    return join( "\n", @lines );
+}
 
 sub package_subs {
     my $class = shift;
