@@ -20,18 +20,14 @@ sub init {
     $self->$_([]) for qw/ before_each before_all after_each after_all /;
 }
 
+build_with 'describe';
+
 export it => sub {
     my $caller = caller;
     no strict 'refs';
     goto &{ $caller . '::tests' };
 };
 
-export describe => sub {
-    Fennec::Workflow->current->add_item(
-        __PACKAGE__->new( @_ )
-    );
-};
-
 for my $name ( qw/ before_each before_all after_each after_all /) {
     export $name => sub(&) {
         my ($sub) = @_;
@@ -95,3 +91,17 @@ sub add_item {
 }
 
 1;
+
+=head1 AUTHORS
+
+Chad Granum L<exodist7@gmail.com>
+
+=head1 COPYRIGHT
+
+Copyright (C) 2010 Chad Granum
+
+Fennec is free software; Standard perl licence.
+
+Fennec is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+FOR A PARTICULAR PURPOSE.  See the license for more details.
